==> ovirt-engine-4.1.0.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/SetNumberOfCpusVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker;

import org.ovirt.engine.core.common.utils.ToStringBuilder;
import org.ovirt.engine.core.common.vdscommands.VdsAndVmIDVDSParametersBase;
import org.ovirt.engine.core.compat.Guid;
import org.ovirt.engine.core.vdsbroker.vdsbroker.VdsBrokerCommand;

public class SetNumberOfCpusVDSCommand<P extends SetNumberOfCpusVDSCommand.Params> extends VdsBrokerCommand<P> {

    public SetNumberOfCpusVDSCommand(P parameters) {
        super(parameters);
    }

    @Override
    protected void executeVdsBrokerCommand() {
        try {
            status = getBroker().setNumberOfCpus(
                    getParameters().getVmId().toString(),
                    String.valueOf(getParameters().getNumberOfCpus()));
            proceedProxyReturnValue();
        } catch (RuntimeException e) {
            setVdsRuntimeError(e);
            // prevent exception handler from rethrowing an exception
            getVDSReturnValue().setExceptionString(null);
        }
    }

    public static class Params extends VdsAndVmIDVDSParametersBase{

        private int numberOfCpus;

        public Params(Guid vdsId, Guid vmId, int numberOfCpus) {
            super(vdsId, vmId);
            this.numberOfCpus = numberOfCpus;
        }

        public int getNumberOfCpus() {
            return numberOfCpus;
        }

        @Override
        protected ToStringBuilder appendAttributes(ToStringBuilder tsb) {
            return super.appendAttributes(tsb).append("numberOfCpus", getNumberOfCpus());
        }
    }
}

==> ovirt-engine-4.3.9.0.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/SetNumberOfCpusVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker;

import org.ovirt.engine.core.common.utils.ToStringBuilder;
import org.ovirt.engine.core.common.vdscommands.VdsAndVmIDVDSParametersBase;
import org.ovirt.engine.core.compat.Guid;
import org.ovirt.engine.core.vdsbroker.vdsbroker.VdsBrokerCommand;

public class SetNumberOfCpusVDSCommand<P extends SetNumberOfCpusVDSCommand.Params> extends VdsBrokerCommand<P> {

    public SetNumberOfCpusVDSCommand(P parameters) {
        super(parameters);
    }

    @Override
    protected void executeVdsBrokerCommand() {
        try {
            status = getBroker().setNumberOfCpus(
                    getParameters().getVmId().toString(),
                    String.valueOf(getParameters().getNumberOfCpus()));
            proceedProxyReturnValue();
        } catch (RuntimeException e) {
            setVdsRuntimeErrorAndReport(e);
            // prevent exception handler from rethrowing an exception
            getVDSReturnValue().setExceptionString(null);
        }
    }

    public static class Params extends VdsAndVmIDVDSParametersBase{

        private int numberOfCpus;

        public Params(Guid vdsId, Guid vmId, int numberOfCpus) {
            super(vdsId, vmId);
            this.numberOfCpus = numberOfCpus;
        }

        public int getNumberOfCpus() {
            return numberOfCpus;
        }

        @Override
        protected ToStringBuilder appendAttributes(ToStringBuilder tsb) {
            return super.appendAttributes(tsb).append("numberOfCpus", getNumberOfCpus());
        }
    }
}
